==> hyades.source_3.0.1.1_20041013_1609.zip: org/eclipse/hyades/test/http/internal/reports/HTTPReportGenerator.java <==
/*******************************************************************************
 * Copyright (c) 2003, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.reports;

import java.util.List;

import org.eclipse.hyades.models.common.testprofile.TPFExecutionResult;
import org.eclipse.hyades.models.common.testprofile.TPFTest;
import org.eclipse.hyades.models.common.util.ExecutionUtil;
import org.eclipse.hyades.test.http.junit.TypeValidator;
import org.eclipse.hyades.ui.report.IReportGenerator;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.swt.widgets.Display;

/**
 * Abstract object to be extended by HTTP report generators
 * @author Ernest Jessee
 */
public abstract class HTTPReportGenerator implements IReportGenerator 
{

	protected StructuredSelection selection;

	protected TPFTest test=null;
	
	protected TPFExecutionResult result = null;
	
	private List results;

	
	public void setUsedClasspath(String arg0)
	{
	}

	/**
	 * returns the file extension for the report to be generated.
	 */
	public String getReportFileExtension(ISelection arg0)
	{
		return "html";
	}

	/**
	 * returns a boolean indicating whether or not this report generator is avalable.	 * 
	 * @param ISelection theSel
	 */
	public boolean isAvailable(ISelection theSel)  
	{ 
		StructuredSelection sel = new StructuredSelection(theSel);
		
		selection = (StructuredSelection)sel.getFirstElement();
		
		if(!(selection.getFirstElement() instanceof TPFTest))
			return false;		
		else
			test = (TPFTest)selection.getFirstElement();
				
		if(!new TypeValidator().isValidType(test.getType()))
			return false;
		results = ExecutionUtil.findExecutionResults(test);	
		return (results.size()>0);
	}

	/**
	 * initialzes the TPFExecutionResult object
	 *
	 */
	protected void initResultSelection()
	{
		
		 if(results.size()>1)
		 {
			 ResultsSelectionWizard wiz = new ResultsSelectionWizard(results);
			 new WizardDialog(Display.getDefault().getActiveShell(),wiz).open();			
			 result=wiz.getSelectedResult();
		 }
		 else if(results.size()==1)
		 {
		 	result = (TPFExecutionResult)results.get(0);
		 }
		 else
			result = null;
		 	
	}

}

==> hyades.source_3.2.0_20041221_1637.zip: org/eclipse/hyades/test/http/internal/reports/HTTPReportGenerator.java <==
/*******************************************************************************
 * Copyright (c) 2003, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.reports;

import java.util.List;

import org.eclipse.hyades.models.common.testprofile.TPFExecutionResult;
import org.eclipse.hyades.models.common.testprofile.TPFTest;
import org.eclipse.hyades.models.common.util.ExecutionUtil;
import org.eclipse.hyades.test.http.junit.TypeValidator;
import org.eclipse.hyades.test.ui.navigator.ITestSuiteProxyNode;
import org.eclipse.hyades.ui.report.IReportGenerator;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.swt.widgets.Display;

/**
 * Abstract object to be extended by HTTP report generators
 * @author Ernest Jessee
 */
public abstract class HTTPReportGenerator implements IReportGenerator 
{

	protected StructuredSelection selection;

	protected TPFTest test=null;
	
	protected TPFExecutionResult result = null;
	
	private List results;

	
	public void setUsedClasspath(String arg0)
	{
	}

	/**
	 * returns the file extension for the report to be generated.
	 */
	public String getReportFileExtension(ISelection arg0)
	{
		return "html";
	}

	/**
	 * returns a boolean indicating whether or not this report generator is avalable.	 * 
	 * @param ISelection theSel
	 */
	public boolean isAvailable(ISelection theSel)  
	{ 
		StructuredSelection sel = new StructuredSelection(theSel);
		
		selection = (StructuredSelection)sel.getFirstElement();
		
		if(!(selection.getFirstElement() instanceof ITestSuiteProxyNode))
			return false;		
		else
			test = ((ITestSuiteProxyNode)selection.getFirstElement()).getTestSuite();
				
		if(!new TypeValidator().isValidType(test.getType()))
			return false;
		results = ExecutionUtil.findExecutionResults(test);	
		return (results.size()>0);
	}

	/**
	 * initialzes the TPFExecutionResult object
	 *
	 */
	protected void initResultSelection()
	{
		
		 if(results.size()>1)
		 {
			 ResultsSelectionWizard wiz = new ResultsSelectionWizard(results);
			 new WizardDialog(Display.getDefault().getActiveShell(),wiz).open();			
			 result=wiz.getSelectedResult();
		 }
		 else if(results.size()==1)
		 {
		 	result = (TPFExecutionResult)results.get(0);
		 }
		 else
			result = null;
		 	
	}

}
